==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/JobManagementUI/src/com/clustercontrol/jobmanagement/composite/ParameterComposite.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.jobmanagement.composite;

import java.util.ArrayList;
import java.util.HashMap;

import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.RowData;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Table;

import com.clustercontrol.bean.JobParamTypeConstant;
import com.clustercontrol.bean.SizeConstant;
import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.dialog.ValidateResult;
import com.clustercontrol.jobmanagement.action.GetParameterTableDefine;
import com.clustercontrol.jobmanagement.bean.JobParameterInfo;
import com.clustercontrol.jobmanagement.bean.ParameterTableDefine;
import com.clustercontrol.jobmanagement.composite.action.ParameterSelectionChangedListener;
import com.clustercontrol.jobmanagement.dialog.ParameterDialog;
import com.clustercontrol.util.Messages;

/**
 * ѥ᡼ݥåȥ饹
 * 
 * @version 2.1.0
 * @since 2.1.0
 */
public class ParameterComposite extends Composite {
	protected CommonTableViewer m_viewer = null;

	protected Button m_createCondition = null;
	protected Button m_modifyCondition = null;
	protected Button m_deleteCondition = null;
	
	protected ArrayList m_paramList = null;
	
	protected Shell m_shell = null;
	
	protected ArrayList m_selectItem = null;
	
	protected String m_parentJobId = null;
	
	protected String m_jobId = null;
	
	/**
	 * 󥹥ȥ饯
	 * 
	 * @param parent
	 * @param style
	 * @since 1.0.0
	 */
	public ParameterComposite(Composite parent, int style) {
		super(parent, style);
		initialize();
		m_shell = this.getShell();
	}
	
	/**
	 * 
	 * 
	 * @since 1.0.0
	 */
	private void initialize() {
		RowLayout layout = new RowLayout();
		layout.type = SWT.VERTICAL;
		layout.spacing = 1;
		layout.marginWidth = 5;
		layout.marginHeight = 5;
		layout.fill = true;
		this.setLayout(layout);
		
		Composite composite = null;
		RowLayout rowLayout = null;
		
		composite = new Composite(this, SWT.NONE);
		rowLayout = new RowLayout();
		rowLayout.type = SWT.VERTICAL;
		composite.setLayout(rowLayout);
		
		Label tableTitle = new Label(composite, SWT.NONE);
		tableTitle.setText(Messages.getString("list"));
		
		Table table = new Table(composite, SWT.BORDER | SWT.H_SCROLL
				| SWT.V_SCROLL | SWT.FULL_SELECTION | SWT.SINGLE);
		table.setHeaderVisible(true);
		table.setLinesVisible(true);
		table.setLayoutData(new RowData(430, 80));
		
		composite = new Composite(composite, SWT.NONE);
		rowLayout = new RowLayout();
		rowLayout.type = SWT.HORIZONTAL;
		rowLayout.spacing = 5;
		composite.setLayout(rowLayout);
		
		//ѥ᡼ɲ
		Label dummy1 = new Label(composite, SWT.NONE);
		dummy1.setLayoutData(new RowData(190, SizeConstant.SIZE_LABEL_HEIGHT));
		m_createCondition = new Button(composite, SWT.NONE);
		m_createCondition.setText(Messages.getString("add"));
		m_createCondition.setLayoutData(new RowData(80,
				SizeConstant.SIZE_BUTTON_HEIGHT));
		m_createCondition.addSelectionListener(new SelectionAdapter() {
			@SuppressWarnings("unchecked")
			public void widgetSelected(SelectionEvent e) {
				ParameterDialog dialog = new ParameterDialog(m_shell);
				if (dialog.open() == IDialogConstants.OK_ID) {
					ArrayList info = dialog.getInputData();
					ArrayList list = (ArrayList) m_viewer.getInput();
					if (list == null) {
						list = new ArrayList();
					}
					list.add(info);
					m_viewer.setInput(list);
				}
			}
		});
		
		//ѥ᡼ѹ
		m_modifyCondition = new Button(composite, SWT.NONE);
		m_modifyCondition.setText(Messages.getString("modify"));
		m_modifyCondition.setLayoutData(new RowData(80,
				SizeConstant.SIZE_BUTTON_HEIGHT));
		m_modifyCondition.addSelectionListener(new SelectionAdapter() {
			@SuppressWarnings("unchecked")
			public void widgetSelected(SelectionEvent e) {
				ParameterDialog dialog = new ParameterDialog(m_shell);
				if (m_selectItem instanceof ArrayList) {
					dialog.setInputData((ArrayList) m_selectItem);
					if (dialog.open() == IDialogConstants.OK_ID) {
						ArrayList info = dialog.getInputData();
						ArrayList list = (ArrayList) m_viewer.getInput();
						list.remove(m_selectItem);
						list.add(info);
						m_selectItem = null;
						m_viewer.setInput(list);
					}
				} else {
					
				}
			}
		});
		
		//ѥ᡼κ
		m_deleteCondition = new Button(composite, SWT.NONE);
		m_deleteCondition.setText(Messages.getString("delete"));
		m_deleteCondition.setLayoutData(new RowData(80,
				SizeConstant.SIZE_BUTTON_HEIGHT));
		m_deleteCondition.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				if (m_selectItem instanceof ArrayList) {
					ArrayList list = (ArrayList) m_viewer.getInput();
					list.remove(m_selectItem);
					m_selectItem = null;
					m_viewer.setInput(list);
				} else {
					
				}
			}
		});

		m_viewer = new CommonTableViewer(table);
		m_viewer.createTableColumn(GetParameterTableDefine.get(),
				ParameterTableDefine.SORT_COLUMN_INDEX,
				ParameterTableDefine.SORT_ORDER);
		m_viewer.addSelectionChangedListener(
				new ParameterSelectionChangedListener(this));
	}
	
	/**
	 * ѥ᡼ȿ
	 *  
	 */
	@SuppressWarnings("unchecked")
	public void reflectParamInfo() {
		if (m_paramList instanceof ArrayList) {
			//ѥ᡼
			ArrayList tableData = new ArrayList();
			for (int i = 0; i < m_paramList.size(); i++) {
				JobParameterInfo info = (JobParameterInfo) m_paramList.get(i);
				ArrayList tableLineData = new ArrayList();
				tableLineData.add(info.getParamId());
				tableLineData.add(new Integer(info.getType()));
				if (info.getType() == JobParamTypeConstant.TYPE_SYSTEM) {
					tableLineData.add("(" + Messages.getString("auto") + ")");
				}
				else if (info.getType() == JobParamTypeConstant.TYPE_USER) {
					tableLineData.add(info.getValue());
				}
				tableLineData.add(info.getDescription());
				tableData.add(tableLineData);
			}
			m_viewer.setInput(tableData);
		}
	}
	
	/**
	 * ѥ᡼
	 * 
	 * @param m_waitRule
	 */
	public void setParamInfo(ArrayList paramList) {
		m_paramList = paramList;
	}
	
	/**
	 * ѥ᡼
	 * 
	 * @return
	 */
	public ArrayList getParamInfo() {
		return m_paramList;
	}
	
	/**
	 * ѥ᡼
	 * 
	 * @return
	 */
	@SuppressWarnings("unchecked")
	public ValidateResult createParamInfo() {
		
		//ѥ᡼Υ󥹥󥹤
		m_paramList = new ArrayList();
		
		//ѥ᡼
		ArrayList tableData = (ArrayList) m_viewer.getInput();
		HashMap map = new HashMap();
		if (tableData instanceof ArrayList) {
			for (int i = 0; i < tableData.size(); i++) {
				ArrayList tableLineData = (ArrayList) tableData.get(i);
				JobParameterInfo info = new JobParameterInfo();
				Integer type = 
					(Integer) tableLineData.get(ParameterTableDefine.TYPE);
				info.setType(type.intValue());
				if (info.getType() == JobParamTypeConstant.TYPE_SYSTEM) {
					info.setParamId((String)tableLineData.get(
							ParameterTableDefine.PARAM_ID));
					info.setDescription((String)tableLineData.get(
							ParameterTableDefine.DESCRIPTION));
				}
				else if (info.getType() == JobParamTypeConstant.TYPE_USER) {
					info.setParamId((String)tableLineData.get(
							ParameterTableDefine.PARAM_ID));
					info.setValue((String)tableLineData.get(
							ParameterTableDefine.VALUE));
					info.setDescription((String)tableLineData.get(
							ParameterTableDefine.DESCRIPTION));
				}
				
				//ʣå
				String checkValue = (String) map.get(info.getParamId());
				if (checkValue == null) {
					m_paramList.add(info);
					map.put(info.getParamId(), new Integer(0));
				}
			}
		}

		return null;
	}
	
	/**
	 * 򥢥ƥ
	 * 
	 * @return
	 */
	public ArrayList getSelectItem() {
		return m_selectItem;
	}
	
	/**
	 * 򥢥ƥ
	 * 
	 * @param selectItem
	 */
	public void setSelectItem(ArrayList selectItem) {
		m_selectItem = selectItem;
	}
	
	/**
	 * @return Returns the m_parentJobId.
	 */
	public String geParentJobId() {
		return m_parentJobId;
	}
	
	/**
	 * @param parentJobId
	 *            The m_parentJobId to set.
	 */
	public void setParentJobId(String parentJobId) {
		m_parentJobId = parentJobId;
	}
	
	/**
	 * @return Returns the m_jobId.
	 */
	public String geJobId() {
		return m_jobId;
	}
	
	/**
	 * @param jobId
	 *            The m_jobId to set.
	 */
	public void setJobId(String jobId) {
		m_jobId = jobId;
	}
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/JobManagementUI/src/com/clustercontrol/jobmanagement/composite/ParameterComposite.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.jobmanagement.composite;

import java.util.ArrayList;
import java.util.HashMap;

import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.RowData;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Table;

import com.clustercontrol.bean.JobParamTypeConstant;
import com.clustercontrol.bean.SizeConstant;
import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.dialog.ValidateResult;
import com.clustercontrol.jobmanagement.action.GetParameterTableDefine;
import com.clustercontrol.jobmanagement.bean.JobParameterInfo;
import com.clustercontrol.jobmanagement.bean.ParameterTableDefine;
import com.clustercontrol.jobmanagement.composite.action.ParameterSelectionChangedListener;
import com.clustercontrol.jobmanagement.dialog.ParameterDialog;
import com.clustercontrol.util.Messages;

/**
 * パラメータコンポジットクラス
 * 
 * @version 2.1.0
 * @since 2.1.0
 */
public class ParameterComposite extends Composite {
	protected CommonTableViewer m_viewer = null;

	protected Button m_createCondition = null;
	protected Button m_modifyCondition = null;
	protected Button m_deleteCondition = null;
	
	protected ArrayList m_paramList = null;
	
	protected Shell m_shell = null;
	
	protected ArrayList m_selectItem = null;
	
	protected String m_parentJobId = null;
	
	protected String m_jobId = null;
	
	/**
	 * コンストラクタ
	 * 
	 * @param parent
	 * @param style
	 * @since 1.0.0
	 */
	public ParameterComposite(Composite parent, int style) {
		super(parent, style);
		initialize();
		m_shell = this.getShell();
	}
	
	/**
	 * 初期化処理
	 * 
	 * @since 1.0.0
	 */
	private void initialize() {
		RowLayout layout = new RowLayout();
		layout.type = SWT.VERTICAL;
		layout.spacing = 1;
		layout.marginWidth = 5;
		layout.marginHeight = 5;
		layout.fill = true;
		this.setLayout(layout);
		
		Composite composite = null;
		RowLayout rowLayout = null;
		
		composite = new Composite(this, SWT.NONE);
		rowLayout = new RowLayout();
		rowLayout.type = SWT.VERTICAL;
		composite.setLayout(rowLayout);
		
		Label tableTitle = new Label(composite, SWT.NONE);
		tableTitle.setText(Messages.getString("list"));
		
		Table table = new Table(composite, SWT.BORDER | SWT.H_SCROLL
				| SWT.V_SCROLL | SWT.FULL_SELECTION | SWT.SINGLE);
		table.setHeaderVisible(true);
		table.setLinesVisible(true);
		table.setLayoutData(new RowData(430, 80));
		
		composite = new Composite(composite, SWT.NONE);
		rowLayout = new RowLayout();
		rowLayout.type = SWT.HORIZONTAL;
		rowLayout.spacing = 5;
		composite.setLayout(rowLayout);
		
		//パラメータの追加
		Label dummy1 = new Label(composite, SWT.NONE);
		dummy1.setLayoutData(new RowData(190, SizeConstant.SIZE_LABEL_HEIGHT));
		m_createCondition = new Button(composite, SWT.NONE);
		m_createCondition.setText(Messages.getString("add"));
		m_createCondition.setLayoutData(new RowData(80,
				SizeConstant.SIZE_BUTTON_HEIGHT));
		m_createCondition.addSelectionListener(new SelectionAdapter() {
			@SuppressWarnings("unchecked")
			public void widgetSelected(SelectionEvent e) {
				ParameterDialog dialog = new ParameterDialog(m_shell);
				if (dialog.open() == IDialogConstants.OK_ID) {
					ArrayList info = dialog.getInputData();
					ArrayList list = (ArrayList) m_viewer.getInput();
					if (list == null) {
						list = new ArrayList();
					}
					list.add(info);
					m_viewer.setInput(list);
				}
			}
		});
		
		//パラメータの変更
		m_modifyCondition = new Button(composite, SWT.NONE);
		m_modifyCondition.setText(Messages.getString("modify"));
		m_modifyCondition.setLayoutData(new RowData(80,
				SizeConstant.SIZE_BUTTON_HEIGHT));
		m_modifyCondition.addSelectionListener(new SelectionAdapter() {
			@SuppressWarnings("unchecked")
			public void widgetSelected(SelectionEvent e) {
				ParameterDialog dialog = new ParameterDialog(m_shell);
				if (m_selectItem instanceof ArrayList) {
					dialog.setInputData((ArrayList) m_selectItem);
					if (dialog.open() == IDialogConstants.OK_ID) {
						ArrayList info = dialog.getInputData();
						ArrayList list = (ArrayList) m_viewer.getInput();
						list.remove(m_selectItem);
						list.add(info);
						m_selectItem = null;
						m_viewer.setInput(list);
					}
				} else {
					
				}
			}
		});
		
		//パラメータの削除
		m_deleteCondition = new Button(composite, SWT.NONE);
		m_deleteCondition.setText(Messages.getString("delete"));
		m_deleteCondition.setLayoutData(new RowData(80,
				SizeConstant.SIZE_BUTTON_HEIGHT));
		m_deleteCondition.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				if (m_selectItem instanceof ArrayList) {
					ArrayList list = (ArrayList) m_viewer.getInput();
					list.remove(m_selectItem);
					m_selectItem = null;
					m_viewer.setInput(list);
				} else {
					
				}
			}
		});

		m_viewer = new CommonTableViewer(table);
		m_viewer.createTableColumn(GetParameterTableDefine.get(),
				ParameterTableDefine.SORT_COLUMN_INDEX,
				ParameterTableDefine.SORT_ORDER);
		m_viewer.addSelectionChangedListener(
				new ParameterSelectionChangedListener(this));
	}
	
	/**
	 * パラメータ情報反映
	 *  
	 */
	@SuppressWarnings("unchecked")
	public void reflectParamInfo() {
		if (m_paramList instanceof ArrayList) {
			//パラメータ設定
			ArrayList tableData = new ArrayList();
			for (int i = 0; i < m_paramList.size(); i++) {
				JobParameterInfo info = (JobParameterInfo) m_paramList.get(i);
				ArrayList tableLineData = new ArrayList();
				tableLineData.add(info.getParamId());
				tableLineData.add(new Integer(info.getType()));
				if (info.getType() == JobParamTypeConstant.TYPE_SYSTEM) {
					tableLineData.add("(" + Messages.getString("auto") + ")");
				}
				else if (info.getType() == JobParamTypeConstant.TYPE_USER) {
					tableLineData.add(info.getValue());
				}
				tableLineData.add(info.getDescription());
				tableData.add(tableLineData);
			}
			m_viewer.setInput(tableData);
		}
	}
	
	/**
	 * パラメータ情報設定
	 * 
	 * @param m_waitRule
	 */
	public void setParamInfo(ArrayList paramList) {
		m_paramList = paramList;
	}
	
	/**
	 * パラメータ情報取得
	 * 
	 * @return
	 */
	public ArrayList getParamInfo() {
		return m_paramList;
	}
	
	/**
	 * パラメータ情報作成
	 * 
	 * @return
	 */
	@SuppressWarnings("unchecked")
	public ValidateResult createParamInfo() {
		
		//パラメータ情報のインスタンスを作成・取得
		m_paramList = new ArrayList();
		
		//パラメータ取得
		ArrayList tableData = (ArrayList) m_viewer.getInput();
		HashMap map = new HashMap();
		if (tableData instanceof ArrayList) {
			for (int i = 0; i < tableData.size(); i++) {
				ArrayList tableLineData = (ArrayList) tableData.get(i);
				JobParameterInfo info = new JobParameterInfo();
				Integer type = 
					(Integer) tableLineData.get(ParameterTableDefine.TYPE);
				info.setType(type.intValue());
				if (info.getType() == JobParamTypeConstant.TYPE_SYSTEM) {
					info.setParamId((String)tableLineData.get(
							ParameterTableDefine.PARAM_ID));
					info.setDescription((String)tableLineData.get(
							ParameterTableDefine.DESCRIPTION));
				}
				else if (info.getType() == JobParamTypeConstant.TYPE_USER) {
					info.setParamId((String)tableLineData.get(
							ParameterTableDefine.PARAM_ID));
					info.setValue((String)tableLineData.get(
							ParameterTableDefine.VALUE));
					info.setDescription((String)tableLineData.get(
							ParameterTableDefine.DESCRIPTION));
				}
				
				//重複チェック
				String checkValue = (String) map.get(info.getParamId());
				if (checkValue == null) {
					m_paramList.add(info);
					map.put(info.getParamId(), new Integer(0));
				}
			}
		}

		return null;
	}
	
	/**
	 * 選択アイテムを取得
	 * 
	 * @return
	 */
	public ArrayList getSelectItem() {
		return m_selectItem;
	}
	
	/**
	 * 選択アイテムを設定
	 * 
	 * @param selectItem
	 */
	public void setSelectItem(ArrayList selectItem) {
		m_selectItem = selectItem;
	}
	
	/**
	 * @return Returns the m_parentJobId.
	 */
	public String geParentJobId() {
		return m_parentJobId;
	}
	
	/**
	 * @param parentJobId
	 *            The m_parentJobId to set.
	 */
	public void setParentJobId(String parentJobId) {
		m_parentJobId = parentJobId;
	}
	
	/**
	 * @return Returns the m_jobId.
	 */
	public String geJobId() {
		return m_jobId;
	}
	
	/**
	 * @param jobId
	 *            The m_jobId to set.
	 */
	public void setJobId(String jobId) {
		m_jobId = jobId;
	}
}
